@@ -63,8 +63,7 @@ ExtractorPostprocessor::ExtractorPostprocessor()
 ExtractorPostprocessor::ExtractorPostprocessor(ExtractorPostprocessor &&) noexcept = default;
 ExtractorPostprocessor::~ExtractorPostprocessor() = default;
 
-void ExtractorPostprocessor::process(const QVector<QVariant> &data)
-{
+void ExtractorPostprocessor::process(const QList<QVariant> &data) {
     d->m_resultFinalized = false;
     d->m_data.reserve(d->m_data.size() + data.size());
     for (auto elem : data) {
@@ -113,8 +112,7 @@ void ExtractorPostprocessor::process(const QVector<QVariant> &data)
     }
 }
 
-QVector<QVariant> ExtractorPostprocessor::result() const
-{
+QList<QVariant> ExtractorPostprocessor::result() const {
     if (!d->m_resultFinalized) {
         // fold elements we have reservations for into those reservations
         for (auto it = d->m_data.begin(); it != d->m_data.end();) {
@@ -463,12 +461,21 @@ KItinerary::Event ExtractorPostprocessorPrivate::processEvent(KItinerary::Event
     return event;
 }
 
+static QString processCurrency(const QString &currency)
+{
+    if (currency.size() != 3 || !std::all_of(currency.begin(), currency.end(), [](QChar c) { return c.isUpper(); })) {
+        return {};
+    }
+    return currency;
+}
+
 Ticket ExtractorPostprocessorPrivate::processTicket(Ticket ticket) const
 {
     ticket.setName(StringUtil::clean(ticket.name()));
     ticket.setTicketNumber(ticket.ticketNumber().simplified());
     ticket.setUnderName(processPerson(ticket.underName()));
     ticket.setTicketedSeat(processSeat(ticket.ticketedSeat()));
+    ticket.setPriceCurrency(processCurrency(ticket.priceCurrency()));
     return ticket;
 }
 
@@ -503,6 +510,7 @@ T ExtractorPostprocessorPrivate::processReservation(T res) const
     res.setPotentialAction(processActions(res.potentialAction()));
     res.setReservationNumber(res.reservationNumber().trimmed());
     res.setProgramMembershipUsed(processProgramMembership(res.programMembershipUsed()));
+    res.setPriceCurrency(processCurrency(res.priceCurrency()));
 
     if (JsonLd::isA<Ticket>(res.reservedTicket())) {
         res.setReservedTicket(processTicket(res.reservedTicket().template value<Ticket>()));
@@ -602,11 +610,7 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
     }
 
     AddressParser addrParser;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     addrParser.setFallbackCountry(KCountry::fromQLocale(QLocale().territory()).alpha2());
-#else
-    addrParser.setFallbackCountry(KCountry::fromQLocale(QLocale().country()).alpha2());
-#endif
     addrParser.parse(addr);
     addr = addrParser.result();
     return addr;
