@@ -12,11 +12,6 @@
 #include <QImage>
 #include <QQmlEngine>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <private/qv4arraybuffer_p.h>
-#include <private/qv4engine_p.h>
-#endif
-
 using namespace KItinerary;
 
 void JsApi::Barcode::setDecoder(const BarcodeDecoder *decoder)
@@ -41,16 +36,12 @@ QJSValue JsApi::Barcode::decodeAztecBinary(const QVariant &img) const
         if (PdfBarcodeUtil::maybeBarcode(pdfImg, BarcodeDecoder::Aztec) == BarcodeDecoder::None) {
             return {};
         }
-        const auto content = m_decoder->decodeBinary(pdfImg.image(), BarcodeDecoder::Aztec);
+        const auto content = m_decoder->decode(pdfImg.image(), BarcodeDecoder::Aztec).toByteArray();
         if (content.isEmpty()) {
             return {};
         }
         const auto engine = qjsEngine(this);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        return QJSValue(engine->handle(), engine->handle()->newArrayBuffer(content)->asReturnedValue());
-#else
         return QJSValue(QJSManagedValue(QVariant(content), engine));
-#endif
     }
     return {};
 }
@@ -69,7 +60,7 @@ QString JsApi::Barcode::decodeAnyBarcode(const QVariant& img) const
 {
     if (img.userType() == qMetaTypeId<PdfImage>()) {
         const auto pdfImg = img.value<PdfImage>();
-        return m_decoder->decodeString(pdfImg.image(), BarcodeDecoder::Any | BarcodeDecoder::IgnoreAspectRatio);
+        return m_decoder->decode(pdfImg.image(), BarcodeDecoder::Any | BarcodeDecoder::IgnoreAspectRatio).toString();
     }
     return {};
 }
@@ -81,7 +72,7 @@ QString JsApi::Barcode::decodeBarcode(const QVariant &img, BarcodeDecoder::Barco
         if (PdfBarcodeUtil::maybeBarcode(pdfImg, hints) == BarcodeDecoder::None) {
             return {};
         }
-        return m_decoder->decodeString(pdfImg.image(), hints);
+        return m_decoder->decode(pdfImg.image(), hints).toString();
     }
     return {};
 }
